#!/bin/csh
#SBATCH --ntasks=24   
#SBATCH -N 1
#SBATCH -p gpuk80   
#SBATCH --job-name=lnn1
#SBATCH -t 15:00:00
#SBATCH --gres=gpu:4

setenv CONV_RSH ssh

# Set Run Length per file
set simt = 5000000

echo Running on host `hostname`
echo Time is `date`
echo Directory is `pwd`
echo This jobs runs on the following processors:

cd $SLURM_SUBMIT_DIR
echo $SLURM_SUBMIT_DIR
pwd

# program


@ krun = 1

if ( -e start.time) then
 @ start = `cat start.time `
else
 @ start = 0                  
endif

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp

set one = one
echo $one > test.file
echo $one
# Execution of the script
module load cuda
module load namd/2.12-ibverbs-smp-cuda
which anmd2
namd2 +p24 +devices 0,1,2,3 dyn.inp > dyn.out
echo $one >> test.file
echo $one

set okay = true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if ( -e dyn.coor && -e dyn.dcd ) then
 @ tsz = `/bin/ls -s dyn.dcd | awk '{print $1}'`
 @ nrm = `grep 'WallClock' dyn.out | wc -l`
 @ nrm1 = `grep 'ERROR: ' dyn.out | wc -l`
 
echo $tsz >> test.file
echo $tsz
echo $nrm >> test.file
echo $nrm
 if ( $tsz > 0 && $nrm == 1 && $nrm1 < 1 ) then
# SUCCESSFUL RUN; COPY RESTART FILE
#  cp dyn.res dyn.rea
# DETERMINE RUN NUMBER
  if ( -e next.seqno ) then
   @ i = `cat next.seqno` 
  else
   @ i = 1
  endif
# Change the new Start Time
@ start = $start + $simt
echo $start > start.time

# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
  foreach fil ( out coor xsc xst vel dcd )
   mv dyn.$fil dyn$i.$fil
  end
  cp dyn$i.xsc dyn.xsc
  cp dyn$i.coor dyn.coor
  cp dyn$i.vel dyn.vel
  gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
# CONDITIONAL END CHECK
  if ( -e last.seqno ) then
    @ l = `cat last.seqno`
    if ( $i == $l ) then
      @ i += 1
      echo $i > next.seqno 
      exit
    endif
  endif

# SUBMIT THE NEXT JOB
# rm ~/namd.$PBS_JOBID
  sleep 5m
  @ i += 1
  echo $i > next.seqno
  ./dyn.scr
  exit
else
# FILE DOESN'T EXIST
 set okay = false
endif
# FILE DOESN'T EXIST
 set okay = false
endif

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if ( $okay == false ) then
 set ts = `date +%m%d.%H%M`
 mv dyn.out dyn.err.$ts
 exit(201)
endif

end

